@@ -673,6 +673,73 @@ font_options_get_variations (PycairoFontOptions *o, PyObject *ignored) {
 }
 #endif
 
+#if CAIRO_VERSION >= CAIRO_VERSION_ENCODE(1, 17, 8)
+static PyObject *
+font_options_set_color_mode (PycairoFontOptions *o, PyObject *args) {
+  cairo_color_mode_t color_mode;
+  int color_mode_arg;
+
+  if (!PyArg_ParseTuple (args, "i:FontOptions.set_color_mode", &color_mode_arg))
+    return NULL;
+
+  color_mode = (cairo_color_mode_t)color_mode_arg;
+
+  cairo_font_options_set_color_mode (o->font_options, color_mode);
+  RETURN_NULL_IF_CAIRO_FONT_OPTIONS_ERROR(o->font_options);
+  Py_RETURN_NONE;
+}
+
+static PyObject *
+font_options_get_color_mode (PycairoFontOptions *o, PyObject *ignored) {
+  RETURN_INT_ENUM (ColorMode, cairo_font_options_get_color_mode (o->font_options));
+}
+
+static PyObject *
+font_options_set_color_palette (PycairoFontOptions *o, PyObject *args) {
+  unsigned int color_palette;
+
+  if (!PyArg_ParseTuple (args, "I:FontOptions.set_color_palette", &color_palette))
+    return NULL;
+
+  cairo_font_options_set_color_palette (o->font_options, color_palette);
+  RETURN_NULL_IF_CAIRO_FONT_OPTIONS_ERROR(o->font_options);
+  Py_RETURN_NONE;
+}
+
+static PyObject *
+font_options_get_color_palette (PycairoFontOptions *o, PyObject *ignored) {
+  return PyLong_FromUnsignedLong (cairo_font_options_get_color_palette (o->font_options));
+}
+
+static PyObject *
+font_options_set_custom_palette_color (PycairoFontOptions *o, PyObject *args) {
+  double red, green, blue, alpha;
+  unsigned int index;
+
+  if (!PyArg_ParseTuple (args, "Idddd:FontOptions.set_custom_palette_color",
+      &index, &red, &green, &blue, &alpha))
+    return NULL;
+
+  cairo_font_options_set_custom_palette_color (o->font_options, index, red, green, blue, alpha);
+  RETURN_NULL_IF_CAIRO_FONT_OPTIONS_ERROR(o->font_options);
+  Py_RETURN_NONE;
+}
+
+static PyObject *
+font_options_get_custom_palette_color (PycairoFontOptions *o, PyObject *args) {
+  double red, green, blue, alpha;
+  unsigned int index;
+  cairo_status_t status;
+
+  if (!PyArg_ParseTuple (args, "I:FontOptions.get_custom_palette_color", &index))
+    return NULL;
+
+  status = cairo_font_options_get_custom_palette_color (o->font_options, index, &red, &green, &blue, &alpha);
+  RETURN_NULL_IF_CAIRO_ERROR (status);
+  return Py_BuildValue("(dddd)", red, green, blue, alpha);
+}
+#endif
+
 static PyObject *
 font_options_get_antialias (PycairoFontOptions *o, PyObject *ignored) {
   RETURN_INT_ENUM (Antialias, cairo_font_options_get_antialias (o->font_options));
@@ -820,6 +887,14 @@ static PyMethodDef font_options_methods[] = {
 #if CAIRO_VERSION >= CAIRO_VERSION_ENCODE(1, 15, 12)
   {"get_variations",    (PyCFunction)font_options_get_variations, METH_NOARGS},
   {"set_variations",    (PyCFunction)font_options_set_variations, METH_VARARGS},
+#endif
+#if CAIRO_VERSION >= CAIRO_VERSION_ENCODE(1, 17, 8)
+  {"get_color_mode",    (PyCFunction)font_options_get_color_mode, METH_NOARGS},
+  {"set_color_mode",    (PyCFunction)font_options_set_color_mode, METH_VARARGS},
+  {"get_color_palette", (PyCFunction)font_options_get_color_palette, METH_NOARGS},
+  {"set_color_palette", (PyCFunction)font_options_set_color_palette, METH_VARARGS},
+  {"get_custom_palette_color", (PyCFunction)font_options_get_custom_palette_color, METH_VARARGS},
+  {"set_custom_palette_color", (PyCFunction)font_options_set_custom_palette_color, METH_VARARGS},
 #endif
   {"get_antialias",     (PyCFunction)font_options_get_antialias,  METH_NOARGS},
   {"get_hint_metrics",  (PyCFunction)font_options_get_hint_metrics,
