@@ -2,8 +2,6 @@
 
 """Create a PDF file for each example"""
 
-from __future__ import print_function
-
 import os
 import sys
 import cairo
@@ -13,7 +11,7 @@ from snippets import get_snippets
 
 def do_snippet(snippet):
     if verbose_mode:
-        print('processing %s' % snippet.name)
+        print(f'processing {snippet.name}')
 
     width_in_inches, height_in_inches = 2, 2
     width_in_points, height_in_points = \
@@ -24,7 +22,7 @@ def do_snippet(snippet):
         os.makedirs(os.path.join("_build", "pdf"))
     except EnvironmentError:
         pass
-    filename = os.path.join("_build", "pdf", "%s.pdf" % snippet.name)
+    filename = os.path.join("_build", "pdf", f"{snippet.name}.pdf")
 
     surface = cairo.PDFSurface(filename, width_in_points, height_in_points)
     cr = cairo.Context(surface)
